"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const entity_1 = require("@expo/entity");
const results_1 = require("@expo/results");
const knex_1 = require("knex");
const nullthrows_1 = __importDefault(require("nullthrows"));
const InvalidTestEntity_1 = __importDefault(require("../testfixtures/InvalidTestEntity"));
const createKnexIntegrationTestEntityCompanionProvider_1 = require("../testfixtures/createKnexIntegrationTestEntityCompanionProvider");
describe('postgres entity integration', () => {
    let knexInstance;
    beforeAll(() => {
        knexInstance = (0, knex_1.knex)({
            client: 'pg',
            connection: {
                user: (0, nullthrows_1.default)(process.env['PGUSER']),
                password: (0, nullthrows_1.default)(process.env['PGPASSWORD']),
                host: 'localhost',
                port: parseInt((0, nullthrows_1.default)(process.env['PGPORT']), 10),
                database: (0, nullthrows_1.default)(process.env['PGDATABASE']),
            },
        });
    });
    beforeEach(async () => {
        await InvalidTestEntity_1.default.createOrTruncatePostgresTable(knexInstance);
    });
    afterAll(async () => {
        await InvalidTestEntity_1.default.dropPostgresTable(knexInstance);
        await knexInstance.destroy();
    });
    describe('invalid operation result counts', () => {
        it('throws after deletion of multiple rows or no rows', async () => {
            const vc = new entity_1.ViewerContext((0, createKnexIntegrationTestEntityCompanionProvider_1.createKnexIntegrationTestEntityCompanionProvider)(knexInstance));
            const entity1 = await (0, results_1.enforceAsyncResult)(InvalidTestEntity_1.default.creator(vc).setField('id', 1).setField('name', 'hello').createAsync());
            await (0, results_1.enforceAsyncResult)(InvalidTestEntity_1.default.creator(vc).setField('id', 1).setField('name', 'world').createAsync());
            await expect(InvalidTestEntity_1.default.deleteAsync(entity1)).rejects.toThrowError('Excessive deletions from database adapter delete');
        });
        it('throws after update of multiple rows', async () => {
            const vc = new entity_1.ViewerContext((0, createKnexIntegrationTestEntityCompanionProvider_1.createKnexIntegrationTestEntityCompanionProvider)(knexInstance));
            const entity1 = await (0, results_1.enforceAsyncResult)(InvalidTestEntity_1.default.creator(vc).setField('id', 1).setField('name', 'hello').createAsync());
            await (0, results_1.enforceAsyncResult)(InvalidTestEntity_1.default.creator(vc).setField('id', 1).setField('name', 'world').createAsync());
            await expect(InvalidTestEntity_1.default.updater(entity1).setField('name', 'blah').enforceUpdateAsync()).rejects.toThrowError('Excessive results from database adapter update');
        });
        it('throws after update of no rows', async () => {
            const vc = new entity_1.ViewerContext((0, createKnexIntegrationTestEntityCompanionProvider_1.createKnexIntegrationTestEntityCompanionProvider)(knexInstance));
            const entity1 = await (0, results_1.enforceAsyncResult)(InvalidTestEntity_1.default.creator(vc).setField('id', 1).setField('name', 'hello').createAsync());
            await InvalidTestEntity_1.default.deleteAsync(entity1);
            await expect(InvalidTestEntity_1.default.updater(entity1).setField('name', 'blah').enforceUpdateAsync()).rejects.toThrowError('Empty results from database adapter update');
        });
    });
});
//# sourceMappingURL=PostgresInvalidSetup-test.js.map