"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const entity_1 = require("@expo/entity");
const knex_1 = require("knex");
function wrapNativePostgresError(error) {
    const ret = translatePostgresError(error);
    if (error.stack) {
        ret.stack = error.stack;
    }
    return ret;
}
function translatePostgresError(error) {
    if (error instanceof knex_1.knex.KnexTimeoutError) {
        return new entity_1.EntityDatabaseAdapterTransientError(error.message, error);
    }
    switch (error.code) {
        case '23502':
            return new entity_1.EntityDatabaseAdapterNotNullConstraintError(error.message, error);
        case '23503':
            return new entity_1.EntityDatabaseAdapterForeignKeyConstraintError(error.message, error);
        case '23505':
            return new entity_1.EntityDatabaseAdapterUniqueConstraintError(error.message, error);
        case '23514':
            return new entity_1.EntityDatabaseAdapterCheckConstraintError(error.message, error);
        case '23P01':
            return new entity_1.EntityDatabaseAdapterExclusionConstraintError(error.message, error);
        default:
            return new entity_1.EntityDatabaseAdapterUnknownError(error.message, error);
    }
}
async function wrapNativePostgresCallAsync(fn) {
    try {
        return await fn();
    }
    catch (e) {
        if (!(e instanceof Error)) {
            throw e;
        }
        throw wrapNativePostgresError(e);
    }
}
exports.default = wrapNativePostgresCallAsync;
//# sourceMappingURL=wrapNativePostgresCallAsync.js.map