"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.ErrorsTestEntityConfiguration = void 0;
const entity_1 = require("@expo/entity");
const foreignTableName = 'foreign_table';
class ErrorsTestEntity extends entity_1.Entity {
    static getCompanionDefinition() {
        return errorsTestEntityCompanionDefinition;
    }
    static async createOrTruncatePostgresTable(knex) {
        await knex.raw('CREATE EXTENSION IF NOT EXISTS "btree_gist"'); // for gist exclusion on varchar
        const tableName = this.getCompanionDefinition().entityConfiguration.tableName;
        const hasForeignTable = await knex.schema.hasTable(foreignTableName);
        if (!hasForeignTable) {
            await knex.schema.createTable(foreignTableName, (table) => {
                table.integer('id').primary();
            });
        }
        const hasTable = await knex.schema.hasTable(tableName);
        if (!hasTable) {
            await knex.schema.createTable(tableName, (table) => {
                table.integer('id').primary();
                table.string('field_non_null').notNullable();
                table.integer('field_foreign_key').references(`${foreignTableName}.id`);
                table.string('field_unique').unique();
                table.integer('check_less_than_5');
                table.string('field_exclusion');
            });
            await knex.raw(`
        ALTER TABLE :tableName:
        ADD CONSTRAINT check_less_than_5_check_constraint
        CHECK (check_less_than_5 IS NULL OR check_less_than_5 < 5);`, {
                tableName,
            });
            await knex.raw(`
        ALTER TABLE :tableName:
        ADD CONSTRAINT field_exclusion_exclusion_constraint
        EXCLUDE USING gist (field_exclusion WITH =);
        `, {
                tableName,
            });
        }
        await knex(tableName).delete();
        await knex(foreignTableName).delete();
    }
    static async dropPostgresTable(knex) {
        const tableName = this.getCompanionDefinition().entityConfiguration.tableName;
        const hasTable = await knex.schema.hasTable(tableName);
        if (hasTable) {
            await knex.schema.dropTable(tableName);
        }
        const hasForeignTable = await knex.schema.hasTable(foreignTableName);
        if (hasForeignTable) {
            await knex.schema.dropTable(foreignTableName);
        }
    }
}
exports.default = ErrorsTestEntity;
class ErrorsTestEntityPrivacyPolicy extends entity_1.EntityPrivacyPolicy {
    constructor() {
        super(...arguments);
        this.createRules = [
            new entity_1.AlwaysAllowPrivacyPolicyRule(),
        ];
        this.readRules = [
            new entity_1.AlwaysAllowPrivacyPolicyRule(),
        ];
        this.updateRules = [
            new entity_1.AlwaysAllowPrivacyPolicyRule(),
        ];
        this.deleteRules = [
            new entity_1.AlwaysAllowPrivacyPolicyRule(),
        ];
    }
}
exports.ErrorsTestEntityConfiguration = new entity_1.EntityConfiguration({
    idField: 'id',
    tableName: 'postgres_test_entities',
    schema: {
        id: new entity_1.IntField({
            columnName: 'id',
        }),
        fieldNonNull: new entity_1.StringField({
            columnName: 'field_non_null',
        }),
        fieldForeignKey: new entity_1.IntField({
            columnName: 'field_foreign_key',
        }),
        fieldUnique: new entity_1.StringField({
            columnName: 'field_unique',
        }),
        checkLessThan5: new entity_1.IntField({
            columnName: 'check_less_than_5',
        }),
        fieldExclusion: new entity_1.StringField({
            columnName: 'field_exclusion',
        }),
        nonExistentColumn: new entity_1.StringField({
            columnName: 'non_existent_column',
        }),
    },
    databaseAdapterFlavor: 'postgres',
    cacheAdapterFlavor: 'redis',
});
const errorsTestEntityCompanionDefinition = new entity_1.EntityCompanionDefinition({
    entityClass: ErrorsTestEntity,
    entityConfiguration: exports.ErrorsTestEntityConfiguration,
    privacyPolicyClass: ErrorsTestEntityPrivacyPolicy,
});
//# sourceMappingURL=ErrorsTestEntity.js.map