"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.invalidTestEntityConfiguration = void 0;
const entity_1 = require("@expo/entity");
class InvalidTestEntity extends entity_1.Entity {
    static getCompanionDefinition() {
        return invalidTestEntityCompanionDefinition;
    }
    static async createOrTruncatePostgresTable(knex) {
        const tableName = this.getCompanionDefinition().entityConfiguration.tableName;
        const hasTable = await knex.schema.hasTable(tableName);
        if (!hasTable) {
            await knex.schema.createTable(tableName, (table) => {
                table.integer('id'); // invalid because ID is not a primary key or unique
                table.string('name');
            });
        }
        await knex.into(tableName).truncate();
    }
    static async dropPostgresTable(knex) {
        const tableName = this.getCompanionDefinition().entityConfiguration.tableName;
        const hasTable = await knex.schema.hasTable(tableName);
        if (hasTable) {
            await knex.schema.dropTable(tableName);
        }
    }
}
exports.default = InvalidTestEntity;
class InvalidTestEntityPrivacyPolicy extends entity_1.EntityPrivacyPolicy {
    constructor() {
        super(...arguments);
        this.createRules = [
            new entity_1.AlwaysAllowPrivacyPolicyRule(),
        ];
        this.readRules = [
            new entity_1.AlwaysAllowPrivacyPolicyRule(),
        ];
        this.updateRules = [
            new entity_1.AlwaysAllowPrivacyPolicyRule(),
        ];
        this.deleteRules = [
            new entity_1.AlwaysAllowPrivacyPolicyRule(),
        ];
    }
}
exports.invalidTestEntityConfiguration = new entity_1.EntityConfiguration({
    idField: 'id',
    tableName: 'postgres_test_entities',
    schema: {
        id: new entity_1.IntField({
            columnName: 'id',
        }),
        name: new entity_1.StringField({
            columnName: 'name',
        }),
    },
    databaseAdapterFlavor: 'postgres',
    cacheAdapterFlavor: 'redis',
});
const invalidTestEntityCompanionDefinition = new entity_1.EntityCompanionDefinition({
    entityClass: InvalidTestEntity,
    entityConfiguration: exports.invalidTestEntityConfiguration,
    privacyPolicyClass: InvalidTestEntityPrivacyPolicy,
});
//# sourceMappingURL=InvalidTestEntity.js.map