"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.postgresTestEntityConfiguration = void 0;
const entity_1 = require("@expo/entity");
class PostgresTestEntity extends entity_1.Entity {
    static getCompanionDefinition() {
        return postgresTestEntityCompanionDefinition;
    }
    static async createOrTruncatePostgresTable(knex) {
        await knex.raw('CREATE EXTENSION IF NOT EXISTS "uuid-ossp"'); // for uuid_generate_v4()
        const tableName = this.getCompanionDefinition().entityConfiguration.tableName;
        const hasTable = await knex.schema.hasTable(tableName);
        if (!hasTable) {
            await knex.schema.createTable(tableName, (table) => {
                table.uuid('id').defaultTo(knex.raw('uuid_generate_v4()')).primary();
                table.string('name');
                table.boolean('has_a_dog');
                table.boolean('has_a_cat');
                table.specificType('string_array', 'text[]');
                table.jsonb('json_array_field');
                table.jsonb('json_object_field');
                table.dateTime('date_field', { useTz: true });
                table.jsonb('maybe_json_array_field');
            });
        }
        await knex.into(tableName).truncate();
    }
    static async dropPostgresTable(knex) {
        const tableName = this.getCompanionDefinition().entityConfiguration.tableName;
        const hasTable = await knex.schema.hasTable(tableName);
        if (hasTable) {
            await knex.schema.dropTable(tableName);
        }
    }
}
exports.default = PostgresTestEntity;
class PostgresTestEntityPrivacyPolicy extends entity_1.EntityPrivacyPolicy {
    constructor() {
        super(...arguments);
        this.createRules = [
            new entity_1.AlwaysAllowPrivacyPolicyRule(),
        ];
        this.readRules = [
            new entity_1.AlwaysAllowPrivacyPolicyRule(),
        ];
        this.updateRules = [
            new entity_1.AlwaysAllowPrivacyPolicyRule(),
        ];
        this.deleteRules = [
            new entity_1.AlwaysAllowPrivacyPolicyRule(),
        ];
    }
}
exports.postgresTestEntityConfiguration = new entity_1.EntityConfiguration({
    idField: 'id',
    tableName: 'postgres_test_entities',
    schema: {
        id: new entity_1.UUIDField({
            columnName: 'id',
            cache: true,
        }),
        name: new entity_1.StringField({
            columnName: 'name',
        }),
        hasADog: new entity_1.BooleanField({
            columnName: 'has_a_dog',
        }),
        hasACat: new entity_1.BooleanField({
            columnName: 'has_a_cat',
        }),
        stringArray: new entity_1.StringArrayField({
            columnName: 'string_array',
        }),
        jsonArrayField: new entity_1.JSONArrayField({
            columnName: 'json_array_field',
        }),
        jsonObjectField: new entity_1.JSONObjectField({
            columnName: 'json_object_field',
        }),
        dateField: new entity_1.DateField({
            columnName: 'date_field',
        }),
        maybeJsonArrayField: new entity_1.MaybeJSONArrayField({
            columnName: 'maybe_json_array_field',
        }),
    },
    databaseAdapterFlavor: 'postgres',
    cacheAdapterFlavor: 'redis',
});
const postgresTestEntityCompanionDefinition = new entity_1.EntityCompanionDefinition({
    entityClass: PostgresTestEntity,
    entityConfiguration: exports.postgresTestEntityConfiguration,
    privacyPolicyClass: PostgresTestEntityPrivacyPolicy,
});
//# sourceMappingURL=PostgresTestEntity.js.map