"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.postgresTestEntityConfiguration = void 0;
const entity_1 = require("@expo/entity");
class PostgresTriggerTestEntity extends entity_1.Entity {
    static getCompanionDefinition() {
        return postgresTestEntityCompanionDefinition;
    }
    static async createOrTruncatePostgresTable(knex) {
        await knex.raw('CREATE EXTENSION IF NOT EXISTS "uuid-ossp"'); // for uuid_generate_v4()
        const tableName = this.getCompanionDefinition().entityConfiguration.tableName;
        const hasTable = await knex.schema.hasTable(tableName);
        if (!hasTable) {
            await knex.schema.createTable(tableName, (table) => {
                table.uuid('id').defaultTo(knex.raw('uuid_generate_v4()')).primary();
                table.string('name');
            });
        }
        await knex.into(tableName).truncate();
    }
    static async dropPostgresTable(knex) {
        const tableName = this.getCompanionDefinition().entityConfiguration.tableName;
        const hasTable = await knex.schema.hasTable(tableName);
        if (hasTable) {
            await knex.schema.dropTable(tableName);
        }
    }
}
exports.default = PostgresTriggerTestEntity;
class PostgresTriggerTestEntityPrivacyPolicy extends entity_1.EntityPrivacyPolicy {
    constructor() {
        super(...arguments);
        this.createRules = [
            new entity_1.AlwaysAllowPrivacyPolicyRule(),
        ];
        this.readRules = [
            new entity_1.AlwaysAllowPrivacyPolicyRule(),
        ];
        this.updateRules = [
            new entity_1.AlwaysAllowPrivacyPolicyRule(),
        ];
        this.deleteRules = [
            new entity_1.AlwaysAllowPrivacyPolicyRule(),
        ];
    }
}
class ThrowConditionallyTrigger extends entity_1.EntityMutationTrigger {
    constructor(fieldName, badValue) {
        super();
        this.fieldName = fieldName;
        this.badValue = badValue;
    }
    async executeAsync(_viewerContext, _queryContext, entity, _mutationInfo) {
        if (entity.getField(this.fieldName) === this.badValue) {
            throw new Error(`${this.fieldName} cannot have value ${this.badValue}`);
        }
    }
}
class ThrowConditionallyNonTransactionalTrigger extends entity_1.EntityNonTransactionalMutationTrigger {
    constructor(fieldName, badValue) {
        super();
        this.fieldName = fieldName;
        this.badValue = badValue;
    }
    async executeAsync(_viewerContext, entity) {
        if (entity.getField(this.fieldName) === this.badValue) {
            throw new Error(`${this.fieldName} cannot have value ${this.badValue}`);
        }
    }
}
exports.postgresTestEntityConfiguration = new entity_1.EntityConfiguration({
    idField: 'id',
    tableName: 'postgres_test_entities',
    schema: {
        id: new entity_1.UUIDField({
            columnName: 'id',
            cache: true,
        }),
        name: new entity_1.StringField({
            columnName: 'name',
        }),
    },
    databaseAdapterFlavor: 'postgres',
    cacheAdapterFlavor: 'redis',
});
const postgresTestEntityCompanionDefinition = new entity_1.EntityCompanionDefinition({
    entityClass: PostgresTriggerTestEntity,
    entityConfiguration: exports.postgresTestEntityConfiguration,
    privacyPolicyClass: PostgresTriggerTestEntityPrivacyPolicy,
    mutationTriggers: () => ({
        beforeCreate: [new ThrowConditionallyTrigger('name', 'beforeCreate')],
        afterCreate: [new ThrowConditionallyTrigger('name', 'afterCreate')],
        beforeUpdate: [new ThrowConditionallyTrigger('name', 'beforeUpdate')],
        afterUpdate: [new ThrowConditionallyTrigger('name', 'afterUpdate')],
        beforeDelete: [new ThrowConditionallyTrigger('name', 'beforeDelete')],
        afterDelete: [new ThrowConditionallyTrigger('name', 'afterDelete')],
        beforeAll: [new ThrowConditionallyTrigger('name', 'beforeAll')],
        afterAll: [new ThrowConditionallyTrigger('name', 'afterAll')],
        afterCommit: [new ThrowConditionallyNonTransactionalTrigger('name', 'afterCommit')],
    }),
});
//# sourceMappingURL=PostgresTriggerTestEntity.js.map